import { ActiveTheme, StoredTheme } from '@/types';
import { ComputedRef, WritableComputedRef } from 'vue';
/**
 * Returns a computed reference to the active theme.
 *
 * @return {ComputedRef<ActiveTheme>} A computed reference to the active theme.
 */
export declare function useTheme(): ComputedRef<ActiveTheme>;
/**
 * Returns a computed writable reference to the stored theme.
 *
 * @return {WritableComputedRef<StoredTheme>} The writable computed reference for the stored theme.
 */
export declare function useStoredTheme(): WritableComputedRef<StoredTheme>;
/**
 * Returns a boolean indicating whether the theme is dark.
 *
 * @return {ComputedRef<boolean>} boolean indicating whether the theme is dark
 */
export declare function useIsDark(): ComputedRef<boolean>;
/**
 * Returns a boolean indicating whether the current theme is light.
 *
 * @return {ComputedRef<boolean>} True if the current theme is light, false otherwise.
 */
export declare function useIsLight(): ComputedRef<boolean>;
