import { ActiveTheme, StoredTheme, ThemeSystemOptions } from '@/types';
/**
 * Represents the theme system.
 *
 * @class ThemeSystem
 */
export declare class ThemeSystem {
    /**
     * Initializes a new instance of the ThemeSystem class with the provided options.
     *
     * @param {ThemeSystemOptions} options - The options for configuring the theme system.
     */
    constructor(options: ThemeSystemOptions);
    /**
     * Media query to detect the user's preferred color scheme.
     *
     * @see {@link https://developer.mozilla.org/en-US/docs/Web/CSS/@media/prefers-color-scheme}
     */
    private mediaquery;
    /**
     * Retrieves the stored theme from local storage.
     *
     * @return {StoredTheme} the stored theme, which can be 'light', 'dark' or 'auto'.
     */
    private getStoredTheme;
    /**
     * Retrieves the active theme based on the stored theme and the media query.
     *
     * @return {ActiveTheme} The active theme, which can be 'light' or 'dark'.
     */
    getTheme(): ActiveTheme;
    /**
     * Sets the theme for the application and optionally stores it in local storage.
     *
     * @param {StoredTheme} theme - the theme to be set
     * @param {boolean} [store=true] - flag indicating whether to store the theme in local storage
     * @return {void}
     */
    setTheme(theme: StoredTheme, store?: boolean): void;
    /**
     * The currently active theme.
     *
     * Can be 'light' or 'dark'
     */
    readonly theme: import("vue").Ref<ActiveTheme, ActiveTheme>;
    /**
     * The currently stored theme.
     *
     * This is the theme that was last set, or 'light' if no theme has been set
     * yet. Can be 'light', 'dark', or 'auto'.
     */
    readonly storedTheme: import("vue").Ref<StoredTheme, StoredTheme>;
}
